/*
  This file will be evaluated by hydra with a call like this:
  hydra_eval_jobs --gc-roots-dir \
    /nix/var/nix/gcroots/per-user/hydra/hydra-roots --argstr \
    system i686-linux --argstr system x86_64-linux --arg \
    nixpkgs "{outPath = ./}" .... release.nix

  Hydra can be installed with "nix-env -i hydra".
*/
with (import ./release-lib.nix);

let
  jobsForDerivations = attrset: pkgs.lib.attrsets.listToAttrs
    (map
      (name: { inherit name;
               value = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };})
      (builtins.attrNames
        (pkgs.lib.attrsets.filterAttrs
          (n: v: (v.type or null) == "derivation")
          attrset)));

in
{

  tarball = import ./make-tarball.nix;

} // (mapTestOn rec {

  a2jmidid = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  aacskeys = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  aangifte2005 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  aangifte2006 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  aangifte2007 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  aangifte2008 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  aangifte2009 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  aangifte2010 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  aangifte2011 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  abc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  abcde = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  abiword = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  acl2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  adobeReader = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  agg = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  alienarena = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  allegro = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  allegro5 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  alliance = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  alsaPlugins = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  alsaPluginWrapper = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  amsn = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  amule = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  amuleDaemon = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  amuleGui = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  androidsdk_4_1 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  andyetitmoves = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ant = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  antlr = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  antlr3 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  apacheAntGcj = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  apacheAntOpenJDK = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  apacheAntOracleJDK = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  apparmor = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  aqbanking = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  arb = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ardour3 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  arora = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  asc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  asciidoc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  asio = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  aspectj = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  asymptote = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  atanks = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  atari800 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ataripp = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  atermjava = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  atk = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  atkmm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  attica = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  aubio = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  auctex = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  audacious = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  audacity = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  autojump = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  automoc4 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  avahi = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  avidemux = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  avogadro = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  awesome = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  aws_mturk_clt = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  axis2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  azureus = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ballAndPaddle = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  bam = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  baresip = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  bazaar = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  beast = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  beret = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ber_metaocaml_003 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  bibletime = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  bibtextools = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  binutils_gold = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  biolib = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  bitcoin = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  bitlbee = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  bitsnbots = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  bittornado = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  bittorrent = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  blackshades = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  blackshadeselite = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  blender = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  blobby = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  blueman = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  bluez = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  boinc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  boomerang = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  boost = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  boost144 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  boost146 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  boost147 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  boost149 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  boost151 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  botan = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  box2d = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  box2d_2_0_1 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  briss = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  bsddb3 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  btanks = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  btrfsProgs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  buildbot = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  bumblebee = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  bup = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  bzflag = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  caelum = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  cairo = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  cairomm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  calf = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  calibre = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  caneda = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  carrier = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  castle_combat = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  cbrowser = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  cc1394 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  cdrdao = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  cflow = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  cgal = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  cgui = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  chatzilla = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  cheetahTemplate = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  chipmunk = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  chromiumWrapper = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  chromium = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  cil = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  cilaterm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  cinelerra = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  cinepaint = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ciopfs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  clang = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  clangUnwrapped = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  clanlib = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  classpath = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  clearsilver = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  clisp = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  clisp_2_44_1 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  clojure = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  clojure_wrapper = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  clooj_wrapper = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  clucene_core_2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  clutter = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  clutter_gtk = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  clutter_gtk_0_10 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  cmakeWithGui = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  cmus = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  coccinelle = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  cogl = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  coin3d = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  comical = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  compiz = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  compton = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  conkeror = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  conky = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  consolekit = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  construo = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  construoBase = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  coq = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  coq_8_3 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  coriander = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  couchdb = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  crack_attack = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  crrcsim = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  cryptsetup = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  cscope = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  csound = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  csslint = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  cudatoolkit = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  cuneiform = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  cups_pdf_filter = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  curlftpfs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  cvs2svn = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  cython = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  d4x = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  darktable = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  dbench = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  dblatex = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  dbus_cplusplus = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  dbus_glib = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  dbus_java = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  dbus_tools = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ddd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  debian_devscripts = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  dejagnu = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  desktop_file_utils = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  devicemapper = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  dia = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  dico = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  directfb = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  directvnc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  disnix = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  disnixos = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  DisnixWebService = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  disper = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  distcc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  distrho = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  djview = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  dmenu = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  dmraid = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  dmtcp = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  dmtx = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  docutils = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  dosbox = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  doxygen_gui = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  dragonegg = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  drbd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  drgeo = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  dropbox = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  dssi = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  dstat = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  duplicity = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  dvdauthor = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  dvswitch = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  dwarf_fortress = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  dwm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  eaglemode = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  easytag = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ec2_api_tools = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ecj = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  eclipses = {
    eclipse_cpp_36 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    eclipse_cpp_37 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    eclipse_modeling_36 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    eclipse_sdk_35 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    eclipse_sdk_36 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    eclipse_sdk_37 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    eclipse_sdk_42 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  };
  ecryptfs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  edk2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  eduke32 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  eggdbus = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  egoboo = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ekiga = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  elasticmq = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  electricsheep = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  elinks = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  emacs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  emacs22 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  emacs23 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  emacs24Packages = {
    autoComplete = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    bbdb = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    calfw = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    cedet = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    coffee = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    colorTheme = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ecb = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    emacsSessionManagement = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    emacsw3m = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    emms = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    flymakeCursor = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gh = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gist = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    graphvizDot = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    haskellMode = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    jabber = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    jade = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    jdee = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    js2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    logito = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    loremIpsum = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    magit = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    maudeMode = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    notmuch = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ocamlMode = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    org = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    org2blog = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    pcache = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    proofgeneral = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    quack = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    rectMark = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    remember = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    scalaMode = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    sunriseCommander = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xmlRpc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  };
  emboss = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  enblendenfuse = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  encfs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  enchant = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  enlightenment = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  epdfview = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  epm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  eprover = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  eql = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  esdl = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  espeakedit = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  etherape = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  euca2ools = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  eukleides = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  evince = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  evolution_data_server = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  evopedia = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  expect = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  exrdisplay = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  extremetuxracer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  exult = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  facile = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  fail2ban = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  fakenes = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  fam = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  farsight2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  farstream = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  fbida = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  fbpanel = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  fdisk = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  feh = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ffado = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ffmpeg = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ffmpeg_0_6_90 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ffmpeg_1_0 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  fileschanged = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  fio = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  firefox = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  firefox13Wrapper = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  firefox17Wrapper = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  firefox36Wrapper = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  flann = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  flashplayer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  flightgear = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  fltk13 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  fltk20 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  fluidsynth = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  fontforgeX = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  foo2zjs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  foursuite = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  framac = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  freecad = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  freeciv = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  freedink = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  freeglut = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  freemind = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  freepv = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  freerdp = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  freerdpUnstable = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  freestyle = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  freetalk = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  freetts = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  fsg = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  fsharp = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  fspot = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ftgl = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ftgl212 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  fuppes = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  fusesmb = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gajim = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gav = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gcj = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gcj44 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gcj46 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gcl = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  GConf3 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gdb = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gdbCross = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gdk_pixbuf = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gdmap = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gdome2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gecko_mediaplayer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  geeqie = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gegl = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gegl_0_0_22 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gemrb = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gensgs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  geoclue = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  geoipjava = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  get_iplayer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  getmail = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gftp = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ghostOne = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ghostscriptX = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  giblib = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gifsicle = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gigedit = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gimp = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gimp_2_8 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gimpPlugins = {
    fourier = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gap = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gimplensfun = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gmic = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    lqrPlugin = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    resynthesizer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    texturize = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ufraw = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    waveletSharpen = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  };
  girara = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  git = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gitAndTools = {
    darcsToGit = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    git2cl = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gitAnnex = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gitBz = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gitFastExport = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gitFull = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gitSubtree = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gitSVN = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    qgit = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    qgitGit = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    stgit = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    svn2git = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    svn2git_kde = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    tig = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  };
  giv = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gkrellm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gl117 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  glestae = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  glew = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  glfw = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  glib = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  glibmm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  glib_networking = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  globulation2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gltron = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  glxinfo = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gmime = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gmtk = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gmu = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gnash = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gnet = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gnokii = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gnome = {
    at_spi = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    GConf = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gconfmm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gnome_control_center = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gnome_desktop = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gnome_doc_utils = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gnome_icon_theme = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gnome_keyring = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gnome_menus = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gnome_panel = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gnome_python = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gnome_session = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gnome_settings_daemon = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gnome_vfs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gnome_vfs_monikers = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gtk = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gtk_doc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gtkglext = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gtkglextmm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gtkhtml = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gtkmm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gtksourceview = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gvfs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libbonobo = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libbonoboui = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libglade = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libglademm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libgnome = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libgnomecanvas = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libgnomecanvasmm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libgnomecups = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libgnomekbd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libgnomeprint = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libgnomeprintui = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libgnomeui = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libgtkhtml = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libgweather = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libIDL = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libsoup = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libunique = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libwnck = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    metacity = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    nautilus = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ORBit2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    pango = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    pangomm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    python_rsvg = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    startup_notification = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    vte = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    zenity = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  };
  gnome_mplayer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gnome_terminator = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gnome_user_docs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gnonlin = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gnucash = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gnu = {
    hurdHeaders = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libpthreadHeaders = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    mach = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    machHeaders = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    mig = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    mig_raw = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  };
  gnumeric = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gnunet = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gnunet08 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gnupg2_1 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gnuplot = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gob2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gobby5 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gobjectIntrospection = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  goffice = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  goffice_0_9 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  goldendict = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  golly = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  goocanvas = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  googleearth = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  google_talk_plugin = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gosmore = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gource = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gparted = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gpgme = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gphoto2fs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gpscorrelate = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gpsd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gqview = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  grantlee = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  graphicsmagick = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  graphicsmagick137 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  graphviz = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  graphviz_2_0 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  grass = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gravit = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  grip = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  grive = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  grub2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  grub2_efi = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gsettings_desktop_schemas = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gsmartcontrol = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gssdp = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gst_ffmpeg = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gst_plugins_bad = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gst_plugins_base = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gst_plugins_good = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gst_plugins_ugly = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gst_python = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gstreamer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gtk3 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gtkdatabox = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gtkdialog = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gtkgnutella = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gtkimageview = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gtkmathview = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gtkmm3 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gtkmozembedsharp = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gtkpod = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gtksharp1 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gtksharp2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gtksourceviewsharp = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gtkspell = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gtkvnc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gtkwave = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gtmess = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gts = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  guileCairo = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  guileGnome = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  guitone = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gupnp = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gupnp_igd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gupnptools = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gutenprint = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gutenprintBin = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gv = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gwenhywfar = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gwrap = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  gxneur = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  hadoop = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  harfbuzz = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  haskellPackages = {
    accelerateCuda = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    accelerateExamples = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    cairo = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    Chart = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    cuda = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    diagrams = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    diagramsCairo = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ghcMod = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gio = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    glade = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    GLFW = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    glib = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gloss = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    GLURaw = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    GLUT = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    GLUT_2_1_1_2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    GLUT_2_1_2_2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    GLUT_2_2_2_1 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    GLUT_2_3_1_0 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gtk = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gtksourceview2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    haskellPlatform = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    haskellPlatform_2009_2_0_2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    haskellPlatform_2010_1_0_0 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    haskellPlatform_2010_2_0_0 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    haskellPlatform_2011_2_0_0 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    haskellPlatform_2011_2_0_1 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    haskellPlatform_2011_4_0_0 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    haskellPlatform_2012_2_0_0 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    HGL = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    hmatrix = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    hp2anyGraph = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    lambdacubeEngine = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    LambdaHack = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    leksah = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    leksahServer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    lhs2tex = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ltk = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    OpenGL = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    OpenGL_2_2_1_1 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    OpenGL_2_2_3_0 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    OpenGL_2_4_0_2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    OpenGL_2_6_0_1 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    OpenGLRaw = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    pakcs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    pango = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    reactiveBananaWx = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    repaAlgorithms = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    repaExamples = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    SDL = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    SDLImage = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    SDLMixer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    SDLTtf = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    splot = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    svgcairo = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    threadscope = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    timeplot = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    uhc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    vacuumCairo = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    wx = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    wxc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    wxcore = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    X11 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    X11Xft = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xmobar = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xmonad = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xmonadContrib = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xmonadExtras = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  };
  haxe = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  heimdall = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  herqq = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  hevea = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  hexen = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  highlight = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  hol_light = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  homebank = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  hplip = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  htmldoc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  httpfs2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  hugin = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  hwloc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  hydraAntLogger = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  hydrogen = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  i3 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  i3lock = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  i7z = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  icbm3d = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  icecat3 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  icecat3Wrapper = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  icecat3Xul = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  icecatXulrunner3 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  icedtea = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  icewm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  idutils = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ikiwiki = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  imagemagick = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  imagemagickBig = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  imlib = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  imlib2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  impressive = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  indilib = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  inkscape = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  instead = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  intelgen4asm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  io = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ion3 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  iotop = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  iprover = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  irrlicht3843 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  irssi = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  isabelle = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  isocodes = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  itk = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  itstool = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  jackaudio = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  jack_capture = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  jackmeter = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  jags = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  jamp = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  javaCup = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  jbidwatcher = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  jboss = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  jboss_mysql_jdbc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  jbrout = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  jclasslib = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  jdiskreport = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  jdk = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  jedit = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  jfsrec = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  jigdo = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  jing_tools = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  jjtraveler = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  jnettop = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  jre = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  jrePlugin = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  jruby165 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  jscoverage = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  json_glib = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  julia = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  jwm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  k3d = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  kaffe = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  kde3 = {
    arts = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdelibs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  };
  kde4 = {
    akonadi = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    akunambol = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    amarok = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    amor = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ark = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    aurorae = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    bangarang = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    basket = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    blinken = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    bluedevil = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    calligra = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    cantor = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    cervisia = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ColorSchemes = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    desktopthemes = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    digikam = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    dolphin_plugins_git = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    dolphin_plugins_svn = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    emoticons = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    filelight = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    filesharing = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gwenview = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    HighResolutionWallpapers = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    IconThemes = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    jovie = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    k3b = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kaccessible = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kadu = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kalgebra = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kalzium = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kamera = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kanagram = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kapptemplate = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kate = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kbibtex = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kbluetooth = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kbruch = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kcachegrind = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kcalc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kcharselect = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kcolorchooser = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kcron = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdeaccessibility = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdeaccounts_plugin = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdeadmin = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdeartwork = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kde_baseapps = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdebindings = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdeedu = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdegames = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdegraphics = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdegraphics_strigi_analyzer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdegraphics_thumbnailers = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdelibs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdemultimedia = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdenetwork = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdenlive = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdepim = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdepimlibs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdepim_runtime = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdeplasma_addons = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kde_runtime = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdesdk = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdesvn = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdetoys = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdeutils = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdevelop = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdevplatform = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kde_wacomtablet = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdewebdev = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kde_workspace = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdf = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdiff3 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kdnssd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kfile_plugins = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kfilereplace = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kfloppy = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kgamma = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kgeography = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kget = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kgpg = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    khangman = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kig = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kile = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kimagemapeditor = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kioslave_perldoc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kioslave_svn = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kipi_plugins = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kiten = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    klettres = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    klinkstatus = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kmag = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kmousetool = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kmouth = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kmplayer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kmplot = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kmtrace = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kmymoney = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    koffice = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kolourpaint = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kommander = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kompare = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    konq_plugins = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    konsole = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    konversation = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kopete = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kpartloader = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kppp = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kprofilemethod = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    krdc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kremotecontrol = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    krename = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    krfb = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kruler = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    krusader = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ksaneplugin = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kscreensaver = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ksnapshot = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ksshaskpass = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kstars = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kstartperf = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ksystemlog = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kteatime = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ktimer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ktorrent = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ktouch = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kturtle = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ktux = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kuickshow = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kuiviewer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kuser = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kwallet = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kwin_styles = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kwooty = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kwordquiz = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.ar = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.bg = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.bs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.ca = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.ca_valencia = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.cs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.da = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.de = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.el = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.en_GB = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.es = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.et = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.eu = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.fi = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.fr = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.ga = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.gl = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.he = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.hr = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.hu = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.ia = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.id = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.is = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.it = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.ja = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.kk = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.km = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.kn = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.ko = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.lt = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.lv = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.nb = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.nds = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.nl = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.nn = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.pa = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.pl = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.pt = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.pt_BR = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.ro = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.ru = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.si = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.sk = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.sl = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.sr = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.sv = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.th = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.tr = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.ug = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.uk = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.wa = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.zh_CN = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    l10n.zh_TW = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libalkimia = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libkdcraw = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libkdeedu = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libkexiv2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libkipi = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libksane = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libktorrent = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libkvkontakte = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    liblikeback = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    lokalize = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    marble = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    mobipocket = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    networkmanagement = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    okteta = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    okular = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    parley = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    partitionManager = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    polkit_kde_agent = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    poxml = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    printer_applet = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    psi = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    pykde4 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    qt4 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    quassel = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    quasselClient = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    quasselDaemon = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    rekonq = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    rocs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    rsibreak = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    scripts = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    semnotes = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    skrooge = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    smokegen = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    smokeqt = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    sounds = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    step = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    strigi_analyzer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    styles = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    superkaramba = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    svgpart = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    sweeper = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    system_config_printer_kde = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    telepathy.accounts_kcm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    telepathy.approver = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    telepathy.auth_handler = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    telepathy.call_ui = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    telepathy.common_internals = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    telepathy.contact_applet = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    telepathy.contact_list = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    telepathy.contact_runner = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    telepathy.filetransfer_handler = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    telepathy.kded_integration_module = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    telepathy.presence_applet = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    telepathy.send_file = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    telepathy.telepathy_logger_qt = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    telepathy.text_ui = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    umbrello = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    wallpapers = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    WeatherWallpapers = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    yakuake = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    zanshin = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  };
  keen4 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  keepassx = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  keepnote = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  keymon = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  keynav = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  kicad = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  kino = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  klavaro = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  kobodeluxe = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  kona = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  kvm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  larswm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  lash = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  lastwatch = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  latencytop = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  lazarus = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ldcpp = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ledger = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ledger3 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  leiningen = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  lensfun = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  leo2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  lesstif = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  lesstif93 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libao = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libassuan2_1 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libatasmart = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libbluedevil = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libbluray = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libcanberra = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libcdr = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libchamplain = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libchamplain_0_6 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libcm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libcroco = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libcxx = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libdbusmenu_qt = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libdevil = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libdmtx = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libdrm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libextractor = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libfixposix = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libgdata = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libgdata_0_6 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libgdiplus = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libgnome_keyring = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libgnome_keyring3 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libgpod = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libgsf = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libgtop = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libgweather = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libimobiledevice = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libinfinity = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  liblapack = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  liblastfm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  liblqr1 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libmatchbox = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libmatthew_java = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libmms = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libmusclecard = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libnice = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libnotify = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  liboil = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libopensc_dnie = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libplist = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libpseudo = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libqalculate = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libQGLViewer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  librecad = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libreoffice = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  librsvg = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libsexy = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libstartup_notification = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libtiger = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libtorrentRasterbar = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libva = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libvdpau = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libviper = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libvirt = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libvisio = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libvncserver = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libvterm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libwmf = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libwnck3 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libwpd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libwpd_08 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libwpg = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libxklavier = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libxml2Python = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  libxmlxx = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  lilv = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  lilypond = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  lincity = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  lingot = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  links2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  linphone = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  linux = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  linuxConsoleTools = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  linuxPackages = {
    acpi_call = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    atheros = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ati_drivers_x11 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    aufs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    aufs_util = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    bbswitch = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    broadcom_sta = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    cryptodev = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    e1000e = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    exmap = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    frandom = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    iscsitarget = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    iwlwifi = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    klibc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    kqemu = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ndiswrapper = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    nvidia_x11 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    nvidia_x11_legacy173 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    nvidia_x11_legacy96 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    openafsClient = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    openiscsi = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    perf = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    spl = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    sysprof = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    systemtap = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    tp_smapi = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    v86d = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    virtualbox = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    virtualboxGuestAdditions = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    wis_go7007 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    zfs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  };
  linuxsampler = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  liquidwar = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  llvm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  lmms = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  log4cxx = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  logstalgica = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  loudmouth = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  love = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  lv2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  lyx = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mailutils = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mars = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  martyr = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  matchbox = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  matita = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  matita_130312 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  maven = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  maxima = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mcabber = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mcelog = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mcomix = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mcrl2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mdbtools = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mdbtools_git = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mediastreamer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mediatomb = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  meld = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mercurial = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mercurialFull = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  merkaartor = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mesa = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  meshlab = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mess = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  metaocaml_3_09 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mhwaveedit = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  micropolis = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  midori = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  midoriWrapper = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  minecraft = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  miniHttpd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mirage = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mitscheme = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mjpegtools = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mkvtoolnix = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mlt = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mmex = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  modemmanager = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mod_python = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mod_wsgi = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mongodb = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mono = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  monodevelop = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  monodoc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  monotone = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  monotoneViz = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mountall = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mozart = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mozilla = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mozplugger = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mp3info = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mpc123 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mpd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mpg321 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mpich2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  MPlayer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mrxvt = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  msilbc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mtdutils = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  multipath_tools = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  multisync = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mumble = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mupdf = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mupen64plus = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  muscleframework = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  muscletool = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mutt = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mygui = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  myguiSvn = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mysql_jdbc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mysqlWorkbench = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  mythtv = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  naev = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  navipowm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  navit = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  nbd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ncbiCTools = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  netbeans = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  netboot = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  netsurf.browser = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  networkmanager = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  networkmanagerapplet = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  networkmanager_pptp = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  networkmanager_pptp_gnome = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  neverball = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  nfsUtils = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ngspice = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ninka = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  njam = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  nmap = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  nodejs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  nodePackages = {
    abbrev = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ansi = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    async = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    backbone = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    bindings = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    browserchannel = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    bson = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    buffertools = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    bytes = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    commander = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    connect = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    cookie = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    crc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    cssmin = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    datetime = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    debug = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    diff = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    eyes = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    formidable = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    fresh = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    fstream = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    glob = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    hat = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    hiredis = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    inherits = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    knox = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    less = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    mime = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    minimatch = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    mkdirp = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    mongodb = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    mrclean = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    nopt = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    npm2nix = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    npmlog = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    optimist = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    options = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    osenv = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    pause = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    policyfile = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    qs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    rbytes = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    redis = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    request = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    requirejs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    rimraf = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    semver = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    send = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    showdown = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    sockjs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    swig = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    tar = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    temp = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    timerstub = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    tinycolor = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    underscore = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    vows = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    which = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    wordwrap = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ws = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    wu = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xmlhttprequest = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    zeparser = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  };
  notmuch = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  nova = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  novaclient = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  nspluginwrapper = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  nss = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  nss_pam_ldapd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  nssTools = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ntop = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ntrack = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  numeric = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  nut = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  nut_2_6_3 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  obexd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  obex_data_server = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  obexfs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  obexftp = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  obnam = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ocaml = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ocaml_3_08_0 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ocaml_3_10_0 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ocaml_3_11_2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ocaml_4_00_1 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ocamlnat = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ocamlPackages = {
    camlidl = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    camlp5_5_strict = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    camlp5_5_transitional = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    camlp5_6_strict = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    camlp5_6_transitional = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    camlzip = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    camomile = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    camomile_0_8_2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    cryptokit = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    findlib = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gmetadom = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    lablgtk = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    lablgtkmathview = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    menhir = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    mldonkey = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ocaml_batteries = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ocaml_cryptgps = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ocaml_expat = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ocaml_extlib = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ocamlgraph = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ocaml_http = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ocaml_lwt = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ocaml_mysql = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ocamlnet = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ocaml_pcre = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ocaml_react = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ocaml_sexplib = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ocaml_sqlite3 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ocaml_ssl = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ocaml_typeconv = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ounit = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    pycaml = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ulex = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ulex08 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  };
  octave = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  octaveHG = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  offlineimap = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ogre = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ogrepaged = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ois = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  omake = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  oneteam = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  opa = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  opal = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  openbabel = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  openbox = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  opencascade = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  opencsg = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  openct = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  opencv = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  opencv_2_1 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  openfire = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  openlierox = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  openobex = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  opensc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  openscad = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  opensc_dnie_wrapper = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  openscenegraph = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  openttd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  opentyrian = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  opera = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  opkg = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  opusTools = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  oraclejdk = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  oraclejre = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  OVMF = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  oxygen_gtk = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pal = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pam_console = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pam_usb = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pan = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pangoxsl = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  panomatic = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  paraview = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  parted = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  parted_2_3 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  path64 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pavucontrol = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pcmciaUtils = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pcsclite = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pdf2djvu = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pdfread = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pdftk = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  perlPackages = {
    Autodia = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    GD = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    GraphViz = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    InlineJava = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    PerlMagick = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    SQLTranslator = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    TextRecordParser = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    X11GUITest = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  };
  petrifoo = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pfstools = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pgadmin = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  philter = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  phonon = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  phonon_backend_gstreamer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  phonon_backend_vlc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pianobooster = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  picard = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  picolisp = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pidgin = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pidginlatex = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pidginlatexSF = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pidginmsnpecan = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pidginotr = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pidginsipe = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pil = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pinentry = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pinta = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pioneers = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pius = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  plan9port = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  plib = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ploticus = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pltScheme = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pmutils = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  policykit = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  polkit = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  polkit_gnome = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  polkit_qt_1 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pommed = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pong3d = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  poppler = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  popplerQt4 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  postgresql_jdbc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pqiv = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  praat = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  prboom = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  prison = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  privateer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  proxychains = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pstack = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ptlib = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pulseaudio = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pure = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  puredata = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  putty = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pycairo = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pycrypto = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pycups = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pydb = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pyexiv2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pygame = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pygobject = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pygtk = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pyGtkGlade = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pyIRCt = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pyMAILt = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pyopenssl = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pyqt4 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pyrex = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pyrex096 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pyside = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pysideApiextractor = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pysideGeneratorrunner = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pysideShiboken = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pysideTools = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pystringtemplate = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  python26 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  python27 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  python26Full = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  python27Full = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  python26Packages = jobsForDerivations pkgs.python26Packages;
  python27Packages = jobsForDerivations pkgs.python27Packages;
  python3 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pythonDBus = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pythonIRClib = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pythonmagick = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pythonSexy = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pyx = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  pyxml = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qca2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qca2_ossl = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qcmm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qemu = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qemu_1_0 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qfsm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qgis = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qi = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qimageblitz = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qjackctl = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qjoypad = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qjson = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qoauth = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qrdecode = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qrupdate = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qsampler = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qshowdiff = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qsynth = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qt3 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qt47 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qt_gstreamer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qtpfsgui = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qtractor = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qtscriptgenerator = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  quake3demo = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  quake3game = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qucs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  quesoglc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  qwt = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  rabbitmq_server = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  racer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  racket = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  rakarrack = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  rapcad = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  rapidsvn = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ratpoison = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  rawtherapee = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  rdesktop = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  rdf4store = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  rdiff_backup = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  recutils = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  redshift = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  relfs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  remmina = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  reptyr = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  rhino = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  rhpl = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  rigsofrods = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  rili = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  rLang = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  rockbox_utility = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  rpm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  rrdtool = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  rssglx = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  rtmpdump = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  rubber = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  rubyLibs.buildr = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  rubyLibs.rjb = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  rxvt = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  rxvt_unicode = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  s3cmd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  sabnzbd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  sakura = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  salut_a_toi = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  samba = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  saneFrontends = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  satallax = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  sauerbraten = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  saxonb = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  sbcl = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  schroedinger = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  scilab = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  scons = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  scorched3d = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  scribus = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  scrot = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  scummvm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  SDL = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  SDL_gfx = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  SDL_image = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  SDL_mixer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  SDL_net = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  SDL_sound = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  SDL_ttf = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  seeks = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  seg3d = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  seleniumRCBin = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  seq24 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  serd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  sfml_git = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  sgtpuzzles = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  shared_mime_info = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  sharedobjects = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  silgraphite = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  simgear = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  simutrans = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  sip = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  six = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  skype = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  slim = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  slock = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  smatch = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  smbnetfs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  smpeg = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  snack = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  snd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  sndBase = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  sofia_sip = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  soi = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  sonic_visualiser = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  soprano = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  soqt = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  sord = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  sourceHighlight = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  spaceOrbit = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  speechd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  speed_dreams = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  spice = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  spidermonkey_185 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  spin = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  spotify = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  spring = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  springLobby = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  sratom = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  sshfsFuse = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ssreflect = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  st = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  stalin = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  stalonetray = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  stardict = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  stardust = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  stellarium = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  strigi = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  stumpwm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  stuntrally = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  sublime = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  subversionClient = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  suil = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  suitesparse = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  superTux = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  superTuxKart = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  surf = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  swh_lv2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  swiProlog = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  swt = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  sylpheed = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  synergy = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  syslogng = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  system_config_printer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  systemd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  t1lib = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  tabbed = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  tahoelafs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  tailor = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  tangogps = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  taskjuggler = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  tbe = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  teamspeak_client = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  teetertorture = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  teeworlds = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  telepathy_farstream = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  telepathy_gabble = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  telepathy_glib = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  telepathy_haze = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  telepathy_logger = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  telepathy_mission_control = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  telepathy_qt = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  telepathy_rakia = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  telepathy_salut = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  tennix = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  texDisser = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  texLive = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  texLiveBeamer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  texLiveCMSuper = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  texLiveContext = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  texLiveExtra = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  texLiveFull = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  texLiveLatexXColor = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  texLiveModerncv = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  texLivePGF = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  texmacs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  thunderbird = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  tigervnc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  tightvnc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  timidity = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  tk = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  tkabber = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  tkcvs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  tkgate = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  tkgate2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  tomcat5 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  tomcat_connectors = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  tomcat_mysql_jdbc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  torchat = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  torcs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  tpm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  trackballs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  trang = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  transmission = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  transmission_remote_gtk = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  trayer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  tremulous = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  tribler = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  trigger = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  truecrypt = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  tulip = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  tvtime = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  twinkle = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  uae = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ubootGuruplug = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ubootNanonote = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  udev = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  udev145 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  udisks = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ufoai = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ufraw = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ultimatestunts = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ultrastardx = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  unclutter = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  unetbootin = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  unison = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  upower = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  uqm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  urbanterror = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  usbmuxd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  uzbl = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  v4l_utils = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  v8 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  vacuum = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  vala = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  vala15 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  vala16 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  valgrind = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  valkyrie = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  vde2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  vdpauinfo = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  vdrift = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  vectoroids = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  veracity = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  vfdecrypt = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  vice = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  vidalia = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  viewMtn = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  vigra = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  viking = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  vimHugeX = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  vimprobable2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  vimprobable2Wrapper = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  virtinst = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  virtmanager = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  virtualgl = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  virtviewer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  vite = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  vkeybd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  vlc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  vncrec = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  vorbisTools = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  vrpn = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  vtk = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  vue = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  vwm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  w3cCSSValidator = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  warmux = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  warsow = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  warzone2100 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  wavesurfer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  wdfs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  webkit = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  webkit_gtk2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  webkitSVN = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  weechat = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  welkin = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  wesnoth = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  wicd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  widelands = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  wine = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  wineWarcraft = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  wings = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  wireshark = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  wkhtmltopdf = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  wmiimenu = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  wmiiSnap = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  wmname = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  wordnet = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  wpa_supplicant_gui = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  wv = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  wv2 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  wvdial = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  wvstreams = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  wxGTK = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  wxGTK29 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  wxmaxima = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  x11 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  x11_ssh_askpass = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  x11vnc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  x2vnc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  x2x = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xalanJava = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xaos = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xapianBindings = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xapianBindings10 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xara = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xautolock = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  Xaw3d = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xawtv = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xbindkeys = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xboard = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xbursttools = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xchat = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xchm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xclip = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xcompmgr = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xconq = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xdaliclock = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xdotool = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xen = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xercesJava = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xf86_input_mtrack = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xf86_input_multitouch = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xf86_input_wacom = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xf86_video_nested = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xf86_video_nouveau = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xfce = {
    exo = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    garcon = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gigolo = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gtk_xfce_engine = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    gvfs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libgdu = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libxfce4ui = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libxfce4util = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libxfcegui4 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    mousepad = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    ristretto = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    terminal = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    thunar = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    thunar_volman = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xfce4_appfinder = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xfce4_cpufreq_plugin = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xfce4icontheme = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xfce4mixer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xfce4panel = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xfce4_power_manager = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xfce4session = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xfce4settings = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xfce4_systemload_plugin = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xfce4_taskmanager = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xfceutils = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xfconf = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xfdesktop = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xfwm4 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  };
  xfig = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xfontsel = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xineLib = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xineUI = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xkeyboard_config = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xlaunch = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xlibs = {
    libAppleWM = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libdmx = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libWindowsWM = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libX11 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libXaw = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libxcb = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libXcomposite = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libXcursor = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libXdamage = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libXext = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libXfixes = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libXft = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libXi = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libXinerama = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libxkbfile = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libXmu = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libXp = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libXpm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libXrandr = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libXrender = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libXres = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libXScrnSaver = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libXt = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libXtst = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libXv = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libXvMC = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libXxf86dga = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libXxf86misc = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    libXxf86vm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    setxkbmap = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    smproxy = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    twm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    x11perf = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xauth = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xbacklight = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xcbproto = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xcbutil = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xcbutilimage = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xcbutilkeysyms = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xcbutilrenderutil = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xcbutilwm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xclock = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xcmsdb = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xcursorgen = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xcursorthemes = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xdm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xdpyinfo = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xdriinfo = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xev = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xeyes = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86inputevdev = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86inputjoystick = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86inputkeyboard = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86inputmouse = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86inputsynaptics = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86inputvmmouse = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86inputvoid = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videoark = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videoast = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videoati = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videocirrus = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videodummy = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videofbdev = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videogeode = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videoglide = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videoglint = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videoi128 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videointel = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videointel_2_14_901 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videointel_2_17_0 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videomach64 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videomga = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videoneomagic = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videonewport = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videonv = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videoopenchrome = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videor128 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videosavage = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videosiliconmotion = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videosis = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videosuncg6 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videosunffb = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videotdfx = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videotga = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videotrident = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videov4l = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videovesa = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videovmware = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videovoodoo = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xf86videowsfb = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xgamma = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xhost = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xinit = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xinput = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xkbcomp = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xkbevd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xkbutils = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xkill = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xlsatoms = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xlsclients = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xmessage = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xmodmap = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xorgserver = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xorgserver_1_13_0 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xpr = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xprop = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xrandr = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xrdb = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xrefresh = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xset = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xsetroot = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xvinfo = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xwd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xwininfo = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    xwud = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  };
  xlockmore = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xlsfonts = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xmacro = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xmlroff = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xmoto = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xmove = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xmpppy = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xnee = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xneur = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xneur_0_8 = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xonotic = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xorg_sys_opengl = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xorgVideoUnichrome = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xoscope = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xosd = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xournal = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xpdf = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xpf = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xplanet = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xpra = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xsane = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xscreensaver = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xsel = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xsokoban = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xsynth_dssi = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xterm = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xtrace = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xtreemfs = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xulrunner = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xvfb_run = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xvidcap = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  xxdiff = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  yate = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  yoshimi = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  youtubeDL = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  zathura = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  zathuraCollection = {
    zathura_core = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    zathura_djvu = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    zathura_pdf_poppler = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
    zathura_ps = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  };
  zbar = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  zdoom = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  zgrviewer = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  zod = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  zoom = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  ZopeInterface = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  zsnes = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  zynaddsubfx = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
  zziplib = { type = "job"; systems = ["x86_64-linux"]; schedulingPriority = 4; };
})
